[gtk+/gtk-style-context] s/GtkStyleSet/GtkStyleProperties/



commit 23051521e08b4282e3a79f66a7352505088d9ec1
Author: Carlos Garnacho <carlosg gnome org>
Date:   Fri Oct 29 06:47:32 2010 +0200

    s/GtkStyleSet/GtkStyleProperties/
    
    The former name had oddities such as gtk_style_set_set() and such,
    so the new name is nicer in that regard and not much longer.

 gtk/Makefile.am                             |    4 +-
 gtk/gtk.h                                   |    2 +-
 gtk/gtkcssprovider.c                        |   22 +-
 gtk/gtksettings.c                           |   16 +-
 gtk/gtkstylecontext.c                       |   28 ++--
 gtk/{gtkstyleset.c => gtkstyleproperties.c} |  336 +++++++++++++-------------
 gtk/gtkstyleproperties.h                    |  115 +++++++++
 gtk/gtkstyleprovider.c                      |    4 +-
 gtk/gtkstyleprovider.h                      |   10 +-
 gtk/gtkstyleset.h                           |  115 ---------
 gtk/gtksymboliccolor.c                      |   42 ++--
 gtk/gtkthemingengine.c                      |    2 +-
 12 files changed, 348 insertions(+), 348 deletions(-)
---
diff --git a/gtk/Makefile.am b/gtk/Makefile.am
index 0247b05..3c06dcd 100644
--- a/gtk/Makefile.am
+++ b/gtk/Makefile.am
@@ -291,8 +291,8 @@ gtk_public_h_sources =          \
 	gtkstatusicon.h		\
 	gtkstock.h		\
 	gtkstylecontext.h	\
+	gtkstyleproperties.h	\
 	gtkstyleprovider.h	\
-	gtkstyleset.h		\
 	gtkstyle.h		\
 	gtksymboliccolor.h	\
 	gtktable.h		\
@@ -578,8 +578,8 @@ gtk_base_c_sources =            \
 	gtkstatusicon.c		\
 	gtkstock.c		\
 	gtkstylecontext.c	\
+	gtkstyleproperties.c	\
 	gtkstyleprovider.c	\
-	gtkstyleset.c		\
 	gtkstyle.c		\
 	gtksymboliccolor.c	\
 	gtktable.c		\
diff --git a/gtk/gtk.h b/gtk/gtk.h
index ba2076c..3c50f44 100644
--- a/gtk/gtk.h
+++ b/gtk/gtk.h
@@ -174,8 +174,8 @@
 #include <gtk/gtkstatusicon.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtkstylecontext.h>
+#include <gtk/gtkstyleproperties.h>
 #include <gtk/gtkstyleprovider.h>
-#include <gtk/gtkstyleset.h>
 #include <gtk/gtkstyle.h>
 #include <gtk/gtksymboliccolor.h>
 #include <gtk/gtktable.h>
diff --git a/gtk/gtkcssprovider.c b/gtk/gtkcssprovider.c
index 0025a59..1af8815 100644
--- a/gtk/gtkcssprovider.c
+++ b/gtk/gtkcssprovider.c
@@ -961,8 +961,8 @@ css_provider_get_selectors (GtkCssProvider *css_provider,
 }
 
 static void
-css_provider_dump_symbolic_colors (GtkCssProvider *css_provider,
-                                   GtkStyleSet    *set)
+css_provider_dump_symbolic_colors (GtkCssProvider     *css_provider,
+                                   GtkStyleProperties *props)
 {
   GtkCssProviderPrivate *priv;
   GHashTableIter iter;
@@ -979,25 +979,25 @@ css_provider_dump_symbolic_colors (GtkCssProvider *css_provider,
       name = key;
       color = value;
 
-      gtk_style_set_map_color (set, name, color);
+      gtk_style_properties_map_color (props, name, color);
     }
 }
 
-static GtkStyleSet *
+static GtkStyleProperties *
 gtk_css_provider_get_style (GtkStyleProvider *provider,
                             GtkWidgetPath    *path)
 {
   GtkCssProvider *css_provider;
   GtkCssProviderPrivate *priv;
-  GtkStyleSet *set;
+  GtkStyleProperties *props;
   GArray *priority_info;
   guint i;
 
   css_provider = GTK_CSS_PROVIDER (provider);
+  props = gtk_style_properties_new ();
   priv = css_provider->priv;
-  set = gtk_style_set_new ();
 
-  css_provider_dump_symbolic_colors (css_provider, set);
+  css_provider_dump_symbolic_colors (css_provider, props);
   priority_info = css_provider_get_selectors (css_provider, path);
 
   for (i = 0; i < priority_info->len; i++)
@@ -1018,16 +1018,16 @@ gtk_css_provider_get_style (GtkStyleProvider *provider,
            * the type is registered or not.
            */
           if (prop[0] == '-' &&
-              !gtk_style_set_lookup_property (prop, NULL, NULL))
+              !gtk_style_properties_lookup_property (prop, NULL, NULL))
             continue;
 
-          gtk_style_set_set_property (set, key, info->state, value);
+          gtk_style_properties_set_property (props, key, info->state, value);
         }
     }
 
   g_array_free (priority_info, TRUE);
 
-  return set;
+  return props;
 }
 
 static gboolean
@@ -2579,7 +2579,7 @@ parse_rule (GtkCssProvider *css_provider,
 
       value_str = g_strstrip (scanner->value.v_identifier);
 
-      if (gtk_style_set_lookup_property (prop, &prop_type, &parse_func))
+      if (gtk_style_properties_lookup_property (prop, &prop_type, &parse_func))
         {
           GValue *val;
 
diff --git a/gtk/gtksettings.c b/gtk/gtksettings.c
index 1fbcee5..12107a1 100644
--- a/gtk/gtksettings.c
+++ b/gtk/gtksettings.c
@@ -1217,19 +1217,19 @@ gtk_settings_class_init (GtkSettingsClass *class)
   g_assert (result == PROP_IM_STATUS_STYLE);
 }
 
-static GtkStyleSet *
+static GtkStyleProperties *
 gtk_settings_get_style (GtkStyleProvider *provider,
                         GtkWidgetPath    *path)
 {
   PangoFontDescription *font_desc;
   gchar *font_name, *color_scheme;
   GtkSettings *settings;
-  GtkStyleSet *set;
+  GtkStyleProperties *props;
   gchar **colors;
   guint i;
 
   settings = GTK_SETTINGS (provider);
-  set = gtk_style_set_new ();
+  props = gtk_style_properties_new ();
 
   g_object_get (settings,
                 "gtk-font-name", &font_name,
@@ -1265,22 +1265,22 @@ gtk_settings_get_style (GtkStyleProvider *provider,
         continue;
 
       color = gtk_symbolic_color_new_literal (&col);
-      gtk_style_set_map_color (set, name, color);
+      gtk_style_properties_map_color (props, name, color);
       gtk_symbolic_color_unref (color);
     }
 
   font_desc = pango_font_description_from_string (font_name);
 
-  gtk_style_set_set (set, 0,
-                     "font", font_desc,
-                     NULL);
+  gtk_style_properties_set (props, 0,
+                            "font", font_desc,
+                            NULL);
 
   pango_font_description_free (font_desc);
   g_strfreev (colors);
   g_free (color_scheme);
   g_free (font_name);
 
-  return set;
+  return props;
 }
 
 static void
diff --git a/gtk/gtkstylecontext.c b/gtk/gtkstylecontext.c
index 602a83d..6479c75 100644
--- a/gtk/gtkstylecontext.c
+++ b/gtk/gtkstylecontext.c
@@ -226,7 +226,7 @@ struct GtkStyleInfo
 
 struct StyleData
 {
-  GtkStyleSet *store;
+  GtkStyleProperties *store;
   GSList *icon_factories;
   GArray *property_cache;
 };
@@ -438,7 +438,7 @@ style_data_new (void)
   StyleData *data;
 
   data = g_slice_new0 (StyleData);
-  data->store = gtk_style_set_new ();
+  data->store = gtk_style_properties_new ();
 
   return data;
 }
@@ -771,7 +771,7 @@ build_properties (GtkStyleContext *context,
   while ((elem = find_next_candidate (list, global_list)) != NULL)
     {
       GtkStyleProviderData *data;
-      GtkStyleSet *provider_style;
+      GtkStyleProperties *provider_style;
 
       data = elem->data;
 
@@ -784,7 +784,7 @@ build_properties (GtkStyleContext *context,
 
       if (provider_style)
         {
-          gtk_style_set_merge (style_data->store, provider_style, TRUE);
+          gtk_style_properties_merge (style_data->store, provider_style, TRUE);
           g_object_unref (provider_style);
         }
     }
@@ -902,9 +902,9 @@ style_data_lookup (GtkStyleContext *context)
   if (priv->theming_engine)
     g_object_unref (priv->theming_engine);
 
-  gtk_style_set_get (data->store, 0,
-                     "engine", &priv->theming_engine,
-                     NULL);
+  gtk_style_properties_get (data->store, 0,
+                            "engine", &priv->theming_engine,
+                            NULL);
   return data;
 }
 
@@ -1198,7 +1198,7 @@ gtk_style_context_get_property (GtkStyleContext *context,
   g_return_if_fail (priv->widget_path != NULL);
 
   data = style_data_lookup (context);
-  gtk_style_set_get_property (data->store, property, state, value);
+  gtk_style_properties_get_property (data->store, property, state, value);
 }
 
 /**
@@ -1225,7 +1225,7 @@ gtk_style_context_get_valist (GtkStyleContext *context,
   g_return_if_fail (priv->widget_path != NULL);
 
   data = style_data_lookup (context);
-  gtk_style_set_get_valist (data->store, state, args);
+  gtk_style_properties_get_valist (data->store, state, args);
 }
 
 /**
@@ -1256,7 +1256,7 @@ gtk_style_context_get (GtkStyleContext *context,
   data = style_data_lookup (context);
 
   va_start (args, state);
-  gtk_style_set_get_valist (data->store, state, args);
+  gtk_style_properties_get_valist (data->store, state, args);
   va_end (args);
 }
 
@@ -2390,7 +2390,7 @@ gtk_style_context_lookup_color (GtkStyleContext *context,
   g_return_val_if_fail (priv->widget_path != NULL, FALSE);
 
   data = style_data_lookup (context);
-  sym_color = gtk_style_set_lookup_color (data->store, color_name);
+  sym_color = gtk_style_properties_lookup_color (data->store, color_name);
 
   if (!sym_color)
     return FALSE;
@@ -2497,9 +2497,9 @@ gtk_style_context_notify_state_change (GtkStyleContext *context,
    * state, it will fallback to the normal state as well if necessary.
    */
   data = style_data_lookup (context);
-  gtk_style_set_get (data->store, flags,
-                     "transition", &desc,
-                     NULL);
+  gtk_style_properties_get (data->store, flags,
+                            "transition", &desc,
+                            NULL);
 
   if (!desc)
     return;
diff --git a/gtk/gtkstyleset.c b/gtk/gtkstyleproperties.c
similarity index 69%
rename from gtk/gtkstyleset.c
rename to gtk/gtkstyleproperties.c
index e856d29..df8529b 100644
--- a/gtk/gtkstyleset.c
+++ b/gtk/gtkstyleproperties.c
@@ -25,14 +25,14 @@
 
 #include "gtktypebuiltins.h"
 #include "gtkstyleprovider.h"
-#include "gtkstyleset.h"
+#include "gtkstyleproperties.h"
 #include "gtkprivate.h"
 #include "gtkthemingengine.h"
 #include "gtkanimationdescription.h"
 #include "gtk9slice.h"
 #include "gtkintl.h"
 
-typedef struct GtkStyleSetPrivate GtkStyleSetPrivate;
+typedef struct GtkStylePropertiesPrivate GtkStylePropertiesPrivate;
 typedef struct PropertyData PropertyData;
 typedef struct PropertyNode PropertyNode;
 typedef struct ValueData ValueData;
@@ -56,7 +56,7 @@ struct PropertyData
   GArray *values;
 };
 
-struct GtkStyleSetPrivate
+struct GtkStylePropertiesPrivate
 {
   GHashTable *color_map;
   GHashTable *properties;
@@ -64,50 +64,50 @@ struct GtkStyleSetPrivate
 
 static GArray *properties = NULL;
 
-static void gtk_style_set_provider_init (GtkStyleProviderIface *iface);
-static void gtk_style_set_finalize      (GObject      *object);
+static void gtk_style_properties_provider_init (GtkStyleProviderIface *iface);
+static void gtk_style_properties_finalize      (GObject      *object);
 
 
-G_DEFINE_TYPE_EXTENDED (GtkStyleSet, gtk_style_set, G_TYPE_OBJECT, 0,
+G_DEFINE_TYPE_EXTENDED (GtkStyleProperties, gtk_style_properties, G_TYPE_OBJECT, 0,
                         G_IMPLEMENT_INTERFACE (GTK_TYPE_STYLE_PROVIDER,
-                                               gtk_style_set_provider_init));
+                                               gtk_style_properties_provider_init));
 
 static void
-gtk_style_set_class_init (GtkStyleSetClass *klass)
+gtk_style_properties_class_init (GtkStylePropertiesClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GValue val = { 0 };
 
-  object_class->finalize = gtk_style_set_finalize;
+  object_class->finalize = gtk_style_properties_finalize;
 
   /* Initialize default property set */
-  gtk_style_set_register_property ("color", GDK_TYPE_RGBA, NULL, NULL);
-  gtk_style_set_register_property ("background-color", GDK_TYPE_RGBA, NULL, NULL);
+  gtk_style_properties_register_property ("color", GDK_TYPE_RGBA, NULL, NULL);
+  gtk_style_properties_register_property ("background-color", GDK_TYPE_RGBA, NULL, NULL);
 
-  gtk_style_set_register_property ("font", PANGO_TYPE_FONT_DESCRIPTION, NULL, NULL);
+  gtk_style_properties_register_property ("font", PANGO_TYPE_FONT_DESCRIPTION, NULL, NULL);
 
-  gtk_style_set_register_property ("margin", GTK_TYPE_BORDER, NULL, NULL);
-  gtk_style_set_register_property ("padding", GTK_TYPE_BORDER, NULL, NULL);
+  gtk_style_properties_register_property ("margin", GTK_TYPE_BORDER, NULL, NULL);
+  gtk_style_properties_register_property ("padding", GTK_TYPE_BORDER, NULL, NULL);
 
-  gtk_style_set_register_property ("border-width", G_TYPE_INT, NULL, NULL);
-  gtk_style_set_register_property ("border-radius", G_TYPE_INT, NULL, NULL);
-  gtk_style_set_register_property ("border-style", GTK_TYPE_BORDER_STYLE, NULL, NULL);
-  gtk_style_set_register_property ("border-color", GDK_TYPE_RGBA, NULL, NULL);
+  gtk_style_properties_register_property ("border-width", G_TYPE_INT, NULL, NULL);
+  gtk_style_properties_register_property ("border-radius", G_TYPE_INT, NULL, NULL);
+  gtk_style_properties_register_property ("border-style", GTK_TYPE_BORDER_STYLE, NULL, NULL);
+  gtk_style_properties_register_property ("border-color", GDK_TYPE_RGBA, NULL, NULL);
 
-  gtk_style_set_register_property ("background-image", CAIRO_GOBJECT_TYPE_PATTERN, NULL, NULL);
-  gtk_style_set_register_property ("border-image", GTK_TYPE_9SLICE, NULL, NULL);
+  gtk_style_properties_register_property ("background-image", CAIRO_GOBJECT_TYPE_PATTERN, NULL, NULL);
+  gtk_style_properties_register_property ("border-image", GTK_TYPE_9SLICE, NULL, NULL);
 
   g_value_init (&val, GTK_TYPE_THEMING_ENGINE);
   g_value_set_object (&val, (GObject *) gtk_theming_engine_load (NULL));
-  gtk_style_set_register_property ("engine", GTK_TYPE_THEMING_ENGINE, &val, NULL);
+  gtk_style_properties_register_property ("engine", GTK_TYPE_THEMING_ENGINE, &val, NULL);
   g_value_unset (&val);
 
   g_value_init (&val, GTK_TYPE_ANIMATION_DESCRIPTION);
   g_value_take_boxed (&val, gtk_animation_description_new (0, GTK_TIMELINE_PROGRESS_LINEAR));
-  gtk_style_set_register_property ("transition", GTK_TYPE_ANIMATION_DESCRIPTION, &val, NULL);
+  gtk_style_properties_register_property ("transition", GTK_TYPE_ANIMATION_DESCRIPTION, &val, NULL);
   g_value_unset (&val);
 
-  g_type_class_add_private (object_class, sizeof (GtkStyleSetPrivate));
+  g_type_class_add_private (object_class, sizeof (GtkStylePropertiesPrivate));
 }
 
 static PropertyData *
@@ -258,46 +258,46 @@ property_data_match_state (PropertyData  *data,
 }
 
 static void
-gtk_style_set_init (GtkStyleSet *set)
+gtk_style_properties_init (GtkStyleProperties *props)
 {
-  GtkStyleSetPrivate *priv;
+  GtkStylePropertiesPrivate *priv;
 
-  priv = set->priv = G_TYPE_INSTANCE_GET_PRIVATE (set,
-                                                  GTK_TYPE_STYLE_SET,
-                                                  GtkStyleSetPrivate);
+  priv = props->priv = G_TYPE_INSTANCE_GET_PRIVATE (props,
+                                                    GTK_TYPE_STYLE_PROPERTIES,
+                                                    GtkStylePropertiesPrivate);
 
   priv->properties = g_hash_table_new_full (NULL, NULL, NULL,
                                             (GDestroyNotify) property_data_free);
 }
 
 static void
-gtk_style_set_finalize (GObject *object)
+gtk_style_properties_finalize (GObject *object)
 {
-  GtkStyleSetPrivate *priv;
-  GtkStyleSet *set;
+  GtkStylePropertiesPrivate *priv;
+  GtkStyleProperties *props;
 
-  set = GTK_STYLE_SET (object);
-  priv = set->priv;
+  props = GTK_STYLE_PROPERTIES (object);
+  priv = props->priv;
   g_hash_table_destroy (priv->properties);
 
   if (priv->color_map)
     g_hash_table_destroy (priv->color_map);
 
-  G_OBJECT_CLASS (gtk_style_set_parent_class)->finalize (object);
+  G_OBJECT_CLASS (gtk_style_properties_parent_class)->finalize (object);
 }
 
-GtkStyleSet *
-gtk_style_set_get_style (GtkStyleProvider *provider,
-                         GtkWidgetPath    *path)
+GtkStyleProperties *
+gtk_style_properties_get_style (GtkStyleProvider *provider,
+                                GtkWidgetPath    *path)
 {
   /* Return style set itself */
   return g_object_ref (provider);
 }
 
 static void
-gtk_style_set_provider_init (GtkStyleProviderIface *iface)
+gtk_style_properties_provider_init (GtkStyleProviderIface *iface)
 {
-  iface->get_style = gtk_style_set_get_style;
+  iface->get_style = gtk_style_properties_get_style;
 }
 
 static int
@@ -335,7 +335,7 @@ property_node_lookup (GQuark quark)
 /* Property registration functions */
 
 /**
- * gtk_style_set_register_property:
+ * gtk_style_properties_register_property:
  * @property_name: property name to register
  * @type: #GType the property will hold
  * @default_value: default value for this property
@@ -349,10 +349,10 @@ property_node_lookup (GQuark quark)
  * Since: 3.0
  **/
 void
-gtk_style_set_register_property (const gchar            *property_name,
-                                 GType                   type,
-                                 const GValue           *default_value,
-                                 GtkStylePropertyParser  parse_func)
+gtk_style_properties_register_property (const gchar            *property_name,
+                                        GType                   type,
+                                        const GValue           *default_value,
+                                        GtkStylePropertyParser  parse_func)
 {
   PropertyNode *node, new = { 0 };
   GQuark quark;
@@ -401,7 +401,7 @@ gtk_style_set_register_property (const gchar            *property_name,
 }
 
 /**
- * gtk_style_set_lookup_property:
+ * gtk_style_properties_lookup_property:
  * @property_name: property name to look up
  * @type: (out): return location for the looked up property type
  * @parse_func: (out): return value for the parse function
@@ -415,19 +415,19 @@ gtk_style_set_register_property (const gchar            *property_name,
  * Since: 3.0
  **/
 gboolean
-gtk_style_set_lookup_property (const gchar            *property_name,
-                               GType                  *type,
-                               GtkStylePropertyParser *parse_func)
+gtk_style_properties_lookup_property (const gchar            *property_name,
+                                      GType                  *type,
+                                      GtkStylePropertyParser *parse_func)
 {
   PropertyNode *node;
-  GtkStyleSetClass *klass;
+  GtkStylePropertiesClass *klass;
   gboolean found = FALSE;
   GQuark quark;
   gint i;
 
   g_return_val_if_fail (property_name != NULL, FALSE);
 
-  klass = g_type_class_ref (GTK_TYPE_STYLE_SET);
+  klass = g_type_class_ref (GTK_TYPE_STYLE_PROPERTIES);
   quark = g_quark_try_string (property_name);
 
   if (quark == 0)
@@ -460,44 +460,44 @@ gtk_style_set_lookup_property (const gchar            *property_name,
   return found;
 }
 
-/* GtkStyleSet methods */
+/* GtkStyleProperties methods */
 
 /**
- * gtk_style_set_new:
+ * gtk_style_properties_new:
  *
- * Returns a newly created #GtkStyleSet
+ * Returns a newly created #GtkStyleProperties
  *
- * Returns: a new #GtkStyleSet
+ * Returns: a new #GtkStyleProperties
  **/
-GtkStyleSet *
-gtk_style_set_new (void)
+GtkStyleProperties *
+gtk_style_properties_new (void)
 {
-  return g_object_new (GTK_TYPE_STYLE_SET, NULL);
+  return g_object_new (GTK_TYPE_STYLE_PROPERTIES, NULL);
 }
 
 /**
- * gtk_style_set_map_color:
- * @set: a #GtkStyleSet
+ * gtk_style_properties_map_color:
+ * @props: a #GtkStyleProperties
  * @name: color name
  * @color: #GtkSymbolicColor to map @name to
  *
  * Maps @color so it can be referenced by @name. See
- * gtk_style_set_lookup_color()
+ * gtk_style_properties_lookup_color()
  *
  * Since: 3.0
  **/
 void
-gtk_style_set_map_color (GtkStyleSet      *set,
-			 const gchar      *name,
-			 GtkSymbolicColor *color)
+gtk_style_properties_map_color (GtkStyleProperties *props,
+                                const gchar        *name,
+                                GtkSymbolicColor   *color)
 {
-  GtkStyleSetPrivate *priv;
+  GtkStylePropertiesPrivate *priv;
 
-  g_return_if_fail (GTK_IS_STYLE_SET (set));
+  g_return_if_fail (GTK_IS_STYLE_PROPERTIES (props));
   g_return_if_fail (name != NULL);
   g_return_if_fail (color != NULL);
 
-  priv = set->priv;
+  priv = props->priv;
 
   if (G_UNLIKELY (!priv->color_map))
     priv->color_map = g_hash_table_new_full (g_str_hash,
@@ -511,8 +511,8 @@ gtk_style_set_map_color (GtkStyleSet      *set,
 }
 
 /**
- * gtk_style_set_lookup_color:
- * @set: a #GtkStyleSet
+ * gtk_style_properties_lookup_color:
+ * @props: a #GtkStyleProperties
  * @name: color name to lookup
  *
  * Returns the symbolic color that is mapped
@@ -523,15 +523,15 @@ gtk_style_set_map_color (GtkStyleSet      *set,
  * Since: 3.0
  **/
 GtkSymbolicColor *
-gtk_style_set_lookup_color (GtkStyleSet *set,
-			    const gchar *name)
+gtk_style_properties_lookup_color (GtkStyleProperties *props,
+                                   const gchar        *name)
 {
-  GtkStyleSetPrivate *priv;
+  GtkStylePropertiesPrivate *priv;
 
-  g_return_val_if_fail (GTK_IS_STYLE_SET (set), NULL);
+  g_return_val_if_fail (GTK_IS_STYLE_PROPERTIES (props), NULL);
   g_return_val_if_fail (name != NULL, NULL);
 
-  priv = set->priv;
+  priv = props->priv;
 
   if (!priv->color_map)
     return NULL;
@@ -540,29 +540,29 @@ gtk_style_set_lookup_color (GtkStyleSet *set,
 }
 
 /**
- * gtk_style_set_set_property:
- * @set: a #GtkStyleSet
+ * gtk_style_properties_set_property:
+ * @props: a #GtkStyleProperties
  * @property: styling property to set
  * @state: state to set the value for
  * @value: new value for the property
  *
- * Sets a styling property in @set.
+ * Sets a styling property in @props.
  *
  * Since: 3.0
  **/
 void
-gtk_style_set_set_property (GtkStyleSet   *set,
-                            const gchar   *property,
-                            GtkStateFlags  state,
-                            const GValue  *value)
+gtk_style_properties_set_property (GtkStyleProperties *props,
+                                   const gchar        *property,
+                                   GtkStateFlags       state,
+                                   const GValue       *value)
 {
-  GtkStyleSetPrivate *priv;
+  GtkStylePropertiesPrivate *priv;
   PropertyNode *node;
   PropertyData *prop;
   GType value_type;
   GValue *val;
 
-  g_return_if_fail (GTK_IS_STYLE_SET (set));
+  g_return_if_fail (GTK_IS_STYLE_PROPERTIES (props));
   g_return_if_fail (property != NULL);
   g_return_if_fail (value != NULL);
 
@@ -589,7 +589,7 @@ gtk_style_set_set_property (GtkStyleSet   *set,
   else
     g_return_if_fail (node->property_type == value_type);
 
-  priv = set->priv;
+  priv = props->priv;
   prop = g_hash_table_lookup (priv->properties,
                               GINT_TO_POINTER (node->property_quark));
 
@@ -617,26 +617,26 @@ gtk_style_set_set_property (GtkStyleSet   *set,
 }
 
 /**
- * gtk_style_set_set_valist:
- * @set: a #GtkStyleSet
+ * gtk_style_properties_set_valist:
+ * @props: a #GtkStyleProperties
  * @state: state to set the values for
  * @args: va_list of property name/value pairs, followed by %NULL
  *
- * Sets several style properties on @set.
+ * Sets several style properties on @props.
  *
  * Since: 3.0
  **/
 void
-gtk_style_set_set_valist (GtkStyleSet   *set,
-                          GtkStateFlags  state,
-                          va_list        args)
+gtk_style_properties_set_valist (GtkStyleProperties *props,
+                                 GtkStateFlags       state,
+                                 va_list             args)
 {
-  GtkStyleSetPrivate *priv;
+  GtkStylePropertiesPrivate *priv;
   const gchar *property_name;
 
-  g_return_if_fail (GTK_IS_STYLE_SET (set));
+  g_return_if_fail (GTK_IS_STYLE_PROPERTIES (props));
 
-  priv = set->priv;
+  priv = props->priv;
   property_name = va_arg (args, const gchar *);
 
   while (property_name)
@@ -686,37 +686,37 @@ gtk_style_set_set_valist (GtkStyleSet   *set,
 }
 
 /**
- * gtk_style_set_set:
- * @set: a #GtkStyleSet
+ * gtk_style_properties_set:
+ * @props: a #GtkStyleProperties
  * @state: state to set the values for
  * @...: property name/value pairs, followed by %NULL
  *
- * Sets several style properties on @set.
+ * Sets several style properties on @props.
  *
  * Since: 3.0
  **/
 void
-gtk_style_set_set (GtkStyleSet   *set,
-                   GtkStateFlags  state,
-                   ...)
+gtk_style_properties_set (GtkStyleProperties *props,
+                          GtkStateFlags       state,
+                          ...)
 {
   va_list args;
 
-  g_return_if_fail (GTK_IS_STYLE_SET (set));
+  g_return_if_fail (GTK_IS_STYLE_PROPERTIES (props));
 
   va_start (args, state);
-  gtk_style_set_set_valist (set, state, args);
+  gtk_style_properties_set_valist (props, state, args);
   va_end (args);
 }
 
 static gboolean
-resolve_color (GtkStyleSet *set,
-	       GValue      *value)
+resolve_color (GtkStyleProperties *props,
+	       GValue             *value)
 {
   GdkRGBA color;
 
   /* Resolve symbolic color to GdkRGBA */
-  if (!gtk_symbolic_color_resolve (g_value_get_boxed (value), set, &color))
+  if (!gtk_symbolic_color_resolve (g_value_get_boxed (value), props, &color))
     return FALSE;
 
   /* Store it back, this is where GdkRGBA caching happens */
@@ -728,12 +728,12 @@ resolve_color (GtkStyleSet *set,
 }
 
 static gboolean
-resolve_gradient (GtkStyleSet *set,
-                  GValue      *value)
+resolve_gradient (GtkStyleProperties *props,
+                  GValue             *value)
 {
   cairo_pattern_t *gradient;
 
-  if (!gtk_gradient_resolve (g_value_get_boxed (value), set, &gradient))
+  if (!gtk_gradient_resolve (g_value_get_boxed (value), props, &gradient))
     return FALSE;
 
   /* Store it back, this is where cairo_pattern_t caching happens */
@@ -745,31 +745,31 @@ resolve_gradient (GtkStyleSet *set,
 }
 
 /**
- * gtk_style_set_get_property:
- * @set: a #GtkStyleSet
+ * gtk_style_properties_get_property:
+ * @props: a #GtkStyleProperties
  * @property: style property name
  * @state: state to retrieve the property value for
  * @value: (out) (transfer full):  return location for the style property value.
  *
- * Gets a style property from @set for the given state. When done with @value,
+ * Gets a style property from @props for the given state. When done with @value,
  * g_value_unset() needs to be called to free any allocated memory.
  *
- * Returns: %TRUE if the property exists in @set, %FALSE otherwise
+ * Returns: %TRUE if the property exists in @props, %FALSE otherwise
  *
  * Since: 3.0
  **/
 gboolean
-gtk_style_set_get_property (GtkStyleSet   *set,
-                            const gchar   *property,
-                            GtkStateFlags  state,
-                            GValue        *value)
+gtk_style_properties_get_property (GtkStyleProperties *props,
+                                   const gchar        *property,
+                                   GtkStateFlags       state,
+                                   GValue             *value)
 {
-  GtkStyleSetPrivate *priv;
+  GtkStylePropertiesPrivate *priv;
   PropertyNode *node;
   PropertyData *prop;
   GValue *val;
 
-  g_return_val_if_fail (GTK_IS_STYLE_SET (set), FALSE);
+  g_return_val_if_fail (GTK_IS_STYLE_PROPERTIES (props), FALSE);
   g_return_val_if_fail (property != NULL, FALSE);
   g_return_val_if_fail (value != NULL, FALSE);
 
@@ -781,7 +781,7 @@ gtk_style_set_get_property (GtkStyleSet   *set,
       return FALSE;
     }
 
-  priv = set->priv;
+  priv = props->priv;
   prop = g_hash_table_lookup (priv->properties,
                               GINT_TO_POINTER (node->property_quark));
 
@@ -801,14 +801,14 @@ gtk_style_set_get_property (GtkStyleSet   *set,
     {
       g_return_val_if_fail (node->property_type == GDK_TYPE_RGBA, FALSE);
 
-      if (!resolve_color (set, val))
+      if (!resolve_color (props, val))
         return FALSE;
     }
   else if (G_VALUE_TYPE (val) == GTK_TYPE_GRADIENT)
     {
       g_return_val_if_fail (node->property_type == CAIRO_GOBJECT_TYPE_PATTERN, FALSE);
 
-      if (!resolve_gradient (set, val))
+      if (!resolve_gradient (props, val))
         return FALSE;
     }
 
@@ -818,26 +818,26 @@ gtk_style_set_get_property (GtkStyleSet   *set,
 }
 
 /**
- * gtk_style_set_get_valist:
- * @set: a #GtkStyleSet
+ * gtk_style_properties_get_valist:
+ * @props: a #GtkStyleProperties
  * @state: state to retrieve the property values for
  * @args: va_list of property name/return location pairs, followed by %NULL
  *
- * Retrieves several style property values from @set for a given state.
+ * Retrieves several style property values from @props for a given state.
  *
  * Since: 3.0
  **/
 void
-gtk_style_set_get_valist (GtkStyleSet   *set,
-                          GtkStateFlags  state,
-                          va_list        args)
+gtk_style_properties_get_valist (GtkStyleProperties *props,
+                                 GtkStateFlags       state,
+                                 va_list             args)
 {
-  GtkStyleSetPrivate *priv;
+  GtkStylePropertiesPrivate *priv;
   const gchar *property_name;
 
-  g_return_if_fail (GTK_IS_STYLE_SET (set));
+  g_return_if_fail (GTK_IS_STYLE_PROPERTIES (props));
 
-  priv = set->priv;
+  priv = props->priv;
   property_name = va_arg (args, const gchar *);
 
   while (property_name)
@@ -868,14 +868,14 @@ gtk_style_set_get_valist (GtkStyleSet   *set,
         {
           g_return_if_fail (node->property_type == GDK_TYPE_RGBA);
 
-          if (!resolve_color (set, val))
+          if (!resolve_color (props, val))
             val = &node->default_value;
         }
       else if (G_VALUE_TYPE (val) == GTK_TYPE_GRADIENT)
         {
           g_return_if_fail (node->property_type == CAIRO_GOBJECT_TYPE_PATTERN);
 
-          if (!resolve_gradient (set, val))
+          if (!resolve_gradient (props, val))
             val = &node->default_value;
         }
 
@@ -893,51 +893,51 @@ gtk_style_set_get_valist (GtkStyleSet   *set,
 }
 
 /**
- * gtk_style_set_get:
- * @set: a #GtkStyleSet
+ * gtk_style_properties_get:
+ * @props: a #GtkStyleProperties
  * @state: state to retrieve the property values for
  * @...: property name /return value pairs, followed by %NULL
  *
- * Retrieves several style property values from @set for a
+ * Retrieves several style property values from @props for a
  * given state.
  *
  * Since: 3.0
  **/
 void
-gtk_style_set_get (GtkStyleSet   *set,
-                   GtkStateFlags  state,
-                   ...)
+gtk_style_properties_get (GtkStyleProperties *props,
+                          GtkStateFlags       state,
+                          ...)
 {
   va_list args;
 
-  g_return_if_fail (GTK_IS_STYLE_SET (set));
+  g_return_if_fail (GTK_IS_STYLE_PROPERTIES (props));
 
   va_start (args, state);
-  gtk_style_set_get_valist (set, state, args);
+  gtk_style_properties_get_valist (props, state, args);
   va_end (args);
 }
 
 /**
- * gtk_style_set_unset_property:
- * @set: a #GtkStyleSet
+ * gtk_style_properties_unset_property:
+ * @props: a #GtkStyleProperties
  * @property: property to unset
  * @state: state to unset
  *
- * Unsets a style property in @set.
+ * Unsets a style property in @props.
  *
  * Since: 3.0
  **/
 void
-gtk_style_set_unset_property (GtkStyleSet   *set,
-                              const gchar   *property,
-                              GtkStateFlags  state)
+gtk_style_properties_unset_property (GtkStyleProperties *props,
+                                     const gchar        *property,
+                                     GtkStateFlags       state)
 {
-  GtkStyleSetPrivate *priv;
+  GtkStylePropertiesPrivate *priv;
   PropertyNode *node;
   PropertyData *prop;
   guint pos;
 
-  g_return_if_fail (GTK_IS_STYLE_SET (set));
+  g_return_if_fail (GTK_IS_STYLE_PROPERTIES (props));
   g_return_if_fail (property != NULL);
 
   node = property_node_lookup (g_quark_try_string (property));
@@ -948,7 +948,7 @@ gtk_style_set_unset_property (GtkStyleSet   *set,
       return;
     }
 
-  priv = set->priv;
+  priv = props->priv;
   prop = g_hash_table_lookup (priv->properties,
                               GINT_TO_POINTER (node->property_quark));
 
@@ -969,49 +969,49 @@ gtk_style_set_unset_property (GtkStyleSet   *set,
 }
 
 /**
- * gtk_style_set_clear:
- * @set: a #GtkStyleSet
+ * gtk_style_properties_clear:
+ * @props: a #GtkStyleProperties
  *
- * Clears all style information from @set.
+ * Clears all style information from @props.
  **/
 void
-gtk_style_set_clear (GtkStyleSet *set)
+gtk_style_properties_clear (GtkStyleProperties *props)
 {
-  GtkStyleSetPrivate *priv;
+  GtkStylePropertiesPrivate *priv;
 
-  g_return_if_fail (GTK_IS_STYLE_SET (set));
+  g_return_if_fail (GTK_IS_STYLE_PROPERTIES (props));
 
-  priv = set->priv;
+  priv = props->priv;
   g_hash_table_remove_all (priv->properties);
 }
 
 /**
- * gtk_style_set_merge:
- * @set: a #GtkStyleSet
- * @set_to_merge: a second #GtkStyleSet
+ * gtk_style_properties_merge:
+ * @props: a #GtkStyleProperties
+ * @props_to_merge: a second #GtkStyleProperties
  * @replace: whether to replace values or not
  *
- * Merges into @set all the style information contained
- * in @set_to_merge. If @replace is %TRUE, the values
+ * Merges into @props all the style information contained
+ * in @props_to_merge. If @replace is %TRUE, the values
  * will be overwritten, if it is %FALSE, the older values
  * will prevail.
  *
  * Since: 3.0
  **/
 void
-gtk_style_set_merge (GtkStyleSet       *set,
-                     const GtkStyleSet *set_to_merge,
-                     gboolean           replace)
+gtk_style_properties_merge (GtkStyleProperties       *props,
+                            const GtkStyleProperties *props_to_merge,
+                            gboolean                  replace)
 {
-  GtkStyleSetPrivate *priv, *priv_to_merge;
+  GtkStylePropertiesPrivate *priv, *priv_to_merge;
   GHashTableIter iter;
   gpointer key, value;
 
-  g_return_if_fail (GTK_IS_STYLE_SET (set));
-  g_return_if_fail (GTK_IS_STYLE_SET (set_to_merge));
+  g_return_if_fail (GTK_IS_STYLE_PROPERTIES (props));
+  g_return_if_fail (GTK_IS_STYLE_PROPERTIES (props_to_merge));
 
-  priv = set->priv;
-  priv_to_merge = set_to_merge->priv;
+  priv = props->priv;
+  priv_to_merge = props_to_merge->priv;
 
   /* Merge symbolic color map */
   if (priv_to_merge->color_map)
@@ -1030,7 +1030,7 @@ gtk_style_set_merge (GtkStyleSet       *set,
               g_hash_table_lookup (priv->color_map, name))
             continue;
 
-          gtk_style_set_map_color (set, name, color);
+          gtk_style_properties_map_color (props, name, color);
         }
     }
 
diff --git a/gtk/gtkstyleproperties.h b/gtk/gtkstyleproperties.h
new file mode 100644
index 0000000..b12c223
--- /dev/null
+++ b/gtk/gtkstyleproperties.h
@@ -0,0 +1,115 @@
+/* GTK - The GIMP Toolkit
+ * Copyright (C) 2010 Carlos Garnacho <carlosg gnome org>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
+#ifndef __GTK_STYLE_PROPERTIES_H__
+#define __GTK_STYLE_PROPERTIES_H__
+
+#include <glib-object.h>
+#include <gdk/gdk.h>
+#include "gtkenums.h"
+#include "gtksymboliccolor.h"
+
+G_BEGIN_DECLS
+
+#define GTK_TYPE_STYLE_PROPERTIES         (gtk_style_properties_get_type ())
+#define GTK_STYLE_PROPERTIES(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), GTK_TYPE_STYLE_PROPERTIES, GtkStyleProperties))
+#define GTK_STYLE_PROPERTIES_CLASS(c)     (G_TYPE_CHECK_CLASS_CAST    ((c), GTK_TYPE_STYLE_PROPERTIES, GtkStylePropertiesClass))
+#define GTK_IS_STYLE_PROPERTIES(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTK_TYPE_STYLE_PROPERTIES))
+#define GTK_IS_STYLE_PROPERTIES_CLASS(c)  (G_TYPE_CHECK_CLASS_TYPE    ((c), GTK_TYPE_STYLE_PROPERTIES))
+#define GTK_STYLE_PROPERTIES_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS  ((o), GTK_TYPE_STYLE_PROPERTIES, GtkStylePropertiesClass))
+
+typedef struct _GtkStyleProperties GtkStyleProperties;
+typedef struct _GtkStylePropertiesClass GtkStylePropertiesClass;
+
+struct _GtkStyleProperties
+{
+  GObject parent_object;
+  gpointer priv;
+};
+
+struct _GtkStylePropertiesClass
+{
+  GObjectClass parent_class;
+};
+
+typedef gboolean (* GtkStylePropertyParser) (const gchar  *string,
+                                             GValue       *value,
+                                             GError      **error);
+
+GType gtk_style_properties_get_type (void) G_GNUC_CONST;
+
+/* Functions to register style properties */
+void     gtk_style_properties_register_property (const gchar            *property_name,
+                                                 GType                   type,
+                                                 const GValue           *default_value,
+                                                 GtkStylePropertyParser  parse_func);
+gboolean gtk_style_properties_lookup_property   (const gchar            *property_name,
+                                                 GType                  *type,
+                                                 GtkStylePropertyParser *parse_func);
+
+GtkStyleProperties * gtk_style_properties_new (void);
+
+void               gtk_style_properties_map_color    (GtkStyleProperties *props,
+                                                      const gchar        *name,
+                                                      GtkSymbolicColor   *color);
+GtkSymbolicColor * gtk_style_properties_lookup_color (GtkStyleProperties *set,
+                                                      const gchar        *name);
+
+void     gtk_style_properties_set_property (GtkStyleProperties *props,
+                                            const gchar        *property,
+                                            GtkStateFlags       state,
+                                            const GValue       *value);
+void     gtk_style_properties_set_valist   (GtkStyleProperties *props,
+                                            GtkStateFlags       state,
+                                            va_list             args);
+void     gtk_style_properties_set          (GtkStyleProperties *props,
+                                            GtkStateFlags       state,
+                                            ...) G_GNUC_NULL_TERMINATED;
+
+gboolean gtk_style_properties_get_property (GtkStyleProperties *props,
+                                            const gchar        *property,
+                                            GtkStateFlags       state,
+                                            GValue             *value);
+void     gtk_style_properties_get_valist   (GtkStyleProperties *props,
+                                            GtkStateFlags       state,
+                                            va_list             args);
+void     gtk_style_properties_get          (GtkStyleProperties *props,
+                                            GtkStateFlags       state,
+                                            ...) G_GNUC_NULL_TERMINATED;
+
+void     gtk_style_properties_unset_property (GtkStyleProperties *props,
+                                              const gchar        *property,
+                                              GtkStateFlags       state);
+
+void     gtk_style_properties_clear          (GtkStyleProperties  *props);
+
+void     gtk_style_properties_merge          (GtkStyleProperties       *props,
+                                              const GtkStyleProperties *props_to_merge,
+                                              gboolean                  replace);
+
+gboolean gtk_symbolic_color_resolve (GtkSymbolicColor    *color,
+				     GtkStyleProperties  *props,
+                                     GdkRGBA             *resolved_color);
+gboolean gtk_gradient_resolve (GtkGradient         *gradient,
+                               GtkStyleProperties  *props,
+                               cairo_pattern_t    **resolved_gradient);
+
+G_END_DECLS
+
+#endif /* __GTK_STYLE_PROPERTIES_H__ */
diff --git a/gtk/gtkstyleprovider.h b/gtk/gtkstyleprovider.h
index 0f763a2..9e67a32 100644
--- a/gtk/gtkstyleprovider.h
+++ b/gtk/gtkstyleprovider.h
@@ -23,7 +23,7 @@
 #include <glib-object.h>
 #include "gtkwidgetpath.h"
 #include "gtkiconfactory.h"
-#include "gtkstyleset.h"
+#include "gtkstyleproperties.h"
 #include "gtkenums.h"
 
 G_BEGIN_DECLS
@@ -52,8 +52,8 @@ struct _GtkStyleProviderIface
 {
   GTypeInterface g_iface;
 
-  GtkStyleSet * (* get_style) (GtkStyleProvider *provider,
-                               GtkWidgetPath    *path);
+  GtkStyleProperties * (* get_style) (GtkStyleProvider *provider,
+                                      GtkWidgetPath    *path);
 
   gboolean (* get_style_property) (GtkStyleProvider *provider,
                                    GtkWidgetPath    *path,
@@ -66,8 +66,8 @@ struct _GtkStyleProviderIface
 
 GType gtk_style_provider_get_type (void) G_GNUC_CONST;
 
-GtkStyleSet *gtk_style_provider_get_style (GtkStyleProvider *provider,
-                                           GtkWidgetPath    *path);
+GtkStyleProperties *gtk_style_provider_get_style (GtkStyleProvider *provider,
+                                                  GtkWidgetPath    *path);
 
 gboolean gtk_style_provider_get_style_property (GtkStyleProvider *provider,
                                                 GtkWidgetPath    *path,
diff --git a/gtk/gtkthemingengine.c b/gtk/gtkthemingengine.c
index 5360ad0..ca3b313 100644
--- a/gtk/gtkthemingengine.c
+++ b/gtk/gtkthemingengine.c
@@ -376,7 +376,7 @@ gtk_theming_engine_register_property (GtkThemingEngine       *engine,
     engine_name = G_OBJECT_TYPE_NAME (engine);
 
   name = g_strdup_printf ("-%s-%s", engine_name, property_name);
-  gtk_style_set_register_property (name, type, default_value, parse_func);
+  gtk_style_properties_register_property (name, type, default_value, parse_func);
   g_free (name);
 }
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gtk/gtkstyleprovider.c b/gtk/gtkstyleprovider.c
index 2a9d2fc..0f1312f 100644
--- a/gtk/gtkstyleprovider.c
+++ b/gtk/gtkstyleprovider.c
@@ -62,11 +62,11 @@ gtk_style_provider_iface_init (gpointer g_iface)
  * Returns the style settings affecting a widget defined by @path, or %NULL if
  * @provider doesn't contemplate styling @path.
  *
  * Returns: a #GtkStyleSet containing the style settings affecting @path
  *
  * Since: 3.0
  **/
-GtkStyleSet *
+GtkStyleProperties *
 gtk_style_provider_get_style (GtkStyleProvider *provider,
                               GtkWidgetPath    *path)
 {
@@ -62,11 +62,11 @@ gtk_style_provider_iface_init (gpointer g_iface)
  * @provider doesn't contemplate styling @path.
  *
- * Returns: a #GtkStyleSet containing the style settings affecting @path
+ * Returns: a #GtkStyleProperties containing the style settings affecting @path
  *
  * Since: 3.0
diff --git a/gtk/gtksymboliccolor.c b/gtk/gtksymboliccolor.c
index f45c8d2..c37313d 100644
--- a/gtk/gtksymboliccolor.c
+++ b/gtk/gtksymboliccolor.c
@@ -19,7 +19,7 @@
 
 #include "config.h"
 #include "gtksymboliccolor.h"
-#include "gtkstyleset.h"
+#include "gtkstyleproperties.h"
 #include "gtkintl.h"
 
 G_DEFINE_BOXED_TYPE (GtkSymbolicColor, gtk_symbolic_color,
@@ -114,7 +114,7 @@ gtk_symbolic_color_new_literal (GdkRGBA *color)
  *
  * Creates a symbolic color pointing to an unresolved named
  * color. See gtk_style_context_lookup_color() and
- * gtk_style_set_lookup_color().
+ * gtk_style_properties_lookup_color().
  *
  * Returns: a newly created #GtkSymbolicColor
  *
@@ -295,25 +295,25 @@ gtk_symbolic_color_unref (GtkSymbolicColor *color)
 /**
  * gtk_symbolic_color_resolve:
  * @color: a #GtkSymbolicColor
  * @style_set: #GtkStyleSet to use when resolving named colors
  * @resolved_color: (out): return location for the resolved color
  *
  * If @color is resolvable, @resolved_color will be filled in
  * with the resolved color, and %TRUE will be returned. Generally,
  * if @color can't be resolved, it is due to it being defined on
  * top of a named color that doesn't exist in @style_set.
  *
  * Returns: %TRUE if the color has been resolved
  *
  * Since: 3.0
  **/
 gboolean
-gtk_symbolic_color_resolve (GtkSymbolicColor *color,
-                            GtkStyleSet      *style_set,
-                            GdkRGBA          *resolved_color)
+gtk_symbolic_color_resolve (GtkSymbolicColor   *color,
+                            GtkStyleProperties *props,
+                            GdkRGBA            *resolved_color)
 {
   g_return_val_if_fail (color != NULL, FALSE);
-  g_return_val_if_fail (GTK_IS_STYLE_SET (style_set), FALSE);
+  g_return_val_if_fail (GTK_IS_STYLE_PROPERTIES (props), FALSE);
   g_return_val_if_fail (resolved_color != NULL, FALSE);
 
   switch (color->type)
@@ -325,12 +325,12 @@ gtk_symbolic_color_resolve (GtkSymbolicColor *color,
       {
         GtkSymbolicColor *named_color;
 
-        named_color = gtk_style_set_lookup_color (style_set, color->name);
+        named_color = gtk_style_properties_lookup_color (props, color->name);
 
         if (!named_color)
           return FALSE;
 
-        return gtk_symbolic_color_resolve (named_color, style_set, resolved_color);
+        return gtk_symbolic_color_resolve (named_color, props, resolved_color);
       }
 
       break;
@@ -338,7 +338,7 @@ gtk_symbolic_color_resolve (GtkSymbolicColor *color,
       {
         GdkRGBA shade;
 
-        if (!gtk_symbolic_color_resolve (color->shade.color, style_set, &shade))
+        if (!gtk_symbolic_color_resolve (color->shade.color, props, &shade))
           return FALSE;
 
         resolved_color->red = CLAMP (shade.red * color->shade.factor, 0, 1);
@@ -354,7 +354,7 @@ gtk_symbolic_color_resolve (GtkSymbolicColor *color,
       {
         GdkRGBA alpha;
 
-        if (!gtk_symbolic_color_resolve (color->alpha.color, style_set, &alpha))
+        if (!gtk_symbolic_color_resolve (color->alpha.color, props, &alpha))
           return FALSE;
 
         *resolved_color = alpha;
@@ -366,10 +366,10 @@ gtk_symbolic_color_resolve (GtkSymbolicColor *color,
       {
         GdkRGBA color1, color2;
 
-        if (!gtk_symbolic_color_resolve (color->mix.color1, style_set, &color1))
+        if (!gtk_symbolic_color_resolve (color->mix.color1, props, &color1))
           return FALSE;
 
-        if (!gtk_symbolic_color_resolve (color->mix.color2, style_set, &color2))
+        if (!gtk_symbolic_color_resolve (color->mix.color2, props, &color2))
           return FALSE;
 
         resolved_color->red = CLAMP (color1.red + ((color2.red - color1.red) * color->mix.factor), 0, 1);
@@ -549,29 +549,29 @@ gtk_gradient_unref (GtkGradient *gradient)
 /**
  * gtk_gradient_resolve:
  * @gradient: a #GtkGradient
  * @style_set: #GtkStyleSet to use when resolving named colors
  * @resolved_gradient: (out): return location for the resolved pattern
  *
  * If @gradient is resolvable, @resolved_gradient will be filled in
  * with the resolved gradient as a cairo_pattern_t, and %TRUE will
  * be returned. Generally, if @gradient can't be resolved, it is
  * due to it being defined on top of a named color that doesn't
- * exist in @style_set.
+ * exist in @props.
  *
  * Returns: %TRUE if the gradient has been resolved
  *
  * Since: 3.0
  **/
 gboolean
-gtk_gradient_resolve (GtkGradient      *gradient,
-                      GtkStyleSet      *style_set,
-                      cairo_pattern_t **resolved_gradient)
+gtk_gradient_resolve (GtkGradient         *gradient,
+                      GtkStyleProperties  *props,
+                      cairo_pattern_t    **resolved_gradient)
 {
   cairo_pattern_t *pattern;
   guint i;
 
   g_return_val_if_fail (gradient != NULL, FALSE);
-  g_return_val_if_fail (GTK_IS_STYLE_SET (style_set), FALSE);
+  g_return_val_if_fail (GTK_IS_STYLE_PROPERTIES (props), FALSE);
   g_return_val_if_fail (resolved_gradient != NULL, FALSE);
 
   if (gradient->radius0 == 0 && gradient->radius1 == 0)
@@ -590,7 +590,7 @@ gtk_gradient_resolve (GtkGradient      *gradient,
 
       stop = &g_array_index (gradient->stops, ColorStop, i);
 
-      if (!gtk_symbolic_color_resolve (stop->color, style_set, &color))
+      if (!gtk_symbolic_color_resolve (stop->color, props, &color))
         {
           cairo_pattern_destroy (pattern);
           return FALSE;
@@ -295,25 +295,25 @@ gtk_symbolic_color_unref (GtkSymbolicColor *color)
  * gtk_symbolic_color_resolve:
  * @color: a #GtkSymbolicColor
- * @style_set: #GtkStyleSet to use when resolving named colors
+ * @props: #GtkStyleProperties to use when resolving named colors
  * @resolved_color: (out): return location for the resolved color
  *
@@ -295,25 +295,25 @@ gtk_symbolic_color_unref (GtkSymbolicColor *color)
  * with the resolved color, and %TRUE will be returned. Generally,
  * if @color can't be resolved, it is due to it being defined on
- * top of a named color that doesn't exist in @style_set.
+ * top of a named color that doesn't exist in @props.
  *
  * Returns: %TRUE if the color has been resolved
@@ -549,29 +549,29 @@ gtk_gradient_unref (GtkGradient *gradient)
  * gtk_gradient_resolve:
  * @gradient: a #GtkGradient
- * @style_set: #GtkStyleSet to use when resolving named colors
+ * @props: #GtkStyleProperties to use when resolving named colors
  * @resolved_gradient: (out): return location for the resolved pattern
  *